@@ -21,7 +21,7 @@ import os
 import math
 import hashlib
 from requests import post
-from typing import Any, Union, List, Dict
+from typing import Any, Union, List, Dict, Optional
 import base64
 
 
@@ -270,7 +270,7 @@ class Client:
         """
         return self.__call("activate_rpc_access", [user_name, api_key])
 
-    def add_collection(self, title: str, parent_id: int = None) -> Union[Dict, None]:
+    def add_collection(self, title: str, parent_id: int = None) -> Optional[Dict]:
         """
         Create a new collection based on 'title'. If 'parent_id' is set,
         will create new collection as child of parent. Otherwise, the new
@@ -356,12 +356,6 @@ class Client:
         """
         return self.__call("add_collection_from_path", [path])
 
-    def add_file_to_collection(self, file_id: int, collection_id: int) -> bool:
-        """
-        DEPRECATED. Do not use. Will be removed later. Use add_resource_to_collection instead.
-        """
-        return self.__call("add_file_to_collection", [file_id, collection_id])
-
     def add_meta_to_collection(
         self, collection_id: int, meta_id: int, meta_value: str
     ) -> Union[int, bool]:
@@ -372,14 +366,6 @@ class Client:
             "add_meta_to_collection", [collection_id, meta_id, meta_value]
         )
 
-    def add_meta_to_file(
-        self, file_id: int, meta_id: int, meta_value: str
-    ) -> Union[int, bool]:
-        """
-        DEPRECATED. Do not use. Will be removed later. Use add_meta_to_resource instead.
-        """
-        return self.__call("add_meta_to_file", [file_id, meta_id, meta_value])
-
     def add_meta_to_resource(
         self, resource_id: int, meta_id: int, meta_value: str
     ) -> Union[int, bool]:
@@ -596,7 +582,7 @@ class Client:
         """
         return self.__call("change_resource_meta_value", [meta_value_id, meta_value])
 
-    def collection(self, collection_id: int) -> Union[Dict, None]:
+    def collection(self, collection_id: int = None) -> Optional[Dict]:
         """
         Get a particular collection given its id.
 
@@ -617,15 +603,31 @@ class Client:
             "tags": [],
         }
         ```
+
+        if collection id is null, will only return the number of collections at root:
+
+        ```
+        {
+            "id": None,
+            "title": "root",
+            "children_count": 25,
+        }
+        ```
         """
         return self.__call("collection", [collection_id])
 
-    def collections(self, parent_id: int = None, recusive: bool = False) -> List[Dict]:
+    def collections(
+        self,
+        parent_id: int = None,
+        recursive: bool = False,
+        limit_from: int = 0,
+        limit_to: int = 2000,
+    ) -> List[Dict]:
         """
         Return the user's collections under the parent collection
         specified by 'parent_id'. If 'parent_id' is null, will return
         collections available at root. If 'recursive' is true, will
-        return all the descendants recusively in the 'children' key.
+        return all the descendants recursively in the 'children' key.
         If recursive is false, 'children' is null.
 
         Example output:
@@ -648,7 +650,7 @@ class Client:
         ]
         ```
         """
-        return self.__call("collections", [parent_id, recusive])
+        return self.__call("collections", [parent_id, recursive, limit_from, limit_to])
 
     def deactivate_rpc_access(self, user_name: str, api_key: str) -> bool:
         """
@@ -668,11 +670,18 @@ class Client:
         """
         return self.__call("delete_collection", [collection_id, recursive])
 
-    def delete_file(self, file_id: int) -> bool:
+    def delete_metadata(self, metadata_id: int) -> bool:
         """
-        DEPRECATED. Do not use. Will be removed later. Use delete_resource instead.
+        Delete metadata based on its id.
         """
-        return self.__call("delete_file", [file_id])
+        return self.__call("delete_metadata", [metadata_id])
+
+    def delete_metadataset(self, metadataset_id: int, recursive: bool = False) -> Dict:
+        """
+        Delete metadata set based on its id. Optional recursive
+        call.
+        """
+        return self.__call("delete_metadataset", [metadataset_id, recursive])
 
     def delete_resource(self, resource_id: int) -> bool:
         """
@@ -680,19 +689,7 @@ class Client:
         """
         return self.__call("delete_resource", [resource_id])
 
-    def file(self, file_id: int) -> Union[Dict, None]:
-        """
-        DEPRECATED. Do not use. Will be removed later. Use resource instead.
-        """
-        return self.__call("file", [file_id])
-
-    def files(self, collection_id: int, include_metas: bool = True) -> List[Dict]:
-        """
-        DEPRECATED. Do not use. Will be removed later. Use resources instead.
-        """
-        return self.__call("files", [collection_id, include_metas])
-
-    def metadata(self, metadata_id: int) -> Union[Dict, None]:
+    def metadata(self, metadata_id: int) -> Optional[Dict]:
         """
         Get one particular metadata given its id.
 
@@ -810,12 +807,6 @@ class Client:
         """
         return self.__call("publish_collection", [collection_id])
 
-    def remove_file_from_collection(self, file_id: int, collection_id: int) -> bool:
-        """
-        DEPRECATED. Do not use. Will be removed later. Use remove_resource_from_collection instead.
-        """
-        return self.__call("remove_file_from_collection", [file_id, collection_id])
-
     def remove_meta_from_collection(
         self, collection_id: int, meta_value_id: int
     ) -> bool:
@@ -826,12 +817,6 @@ class Client:
             "remove_meta_from_collection", [collection_id, meta_value_id]
         )
 
-    def remove_meta_from_file(self, file_id: int, meta_value_id: int) -> bool:
-        """
-        DEPRECATED. Do not use. Will be removed later. Use remove_meta_from_resource instead.
-        """
-        return self.__call("remove_meta_from_file", [file_id, meta_value_id])
-
     def remove_meta_from_resource(self, resource_id: int, meta_value_id: int) -> bool:
         """
         Remove a meta from a resource given their ids.
@@ -874,12 +859,6 @@ class Client:
         """
         return self.__call("rename_collection", [collection_id, title])
 
-    def rename_file(self, file_id: int, title: str) -> bool:
-        """
-        DEPRECATED. Do not use. Will be removed later. Use rename_resource instead.
-        """
-        return self.__call("rename_file", [file_id, title])
-
     def rename_meta(self, meta_id: int, title: str) -> bool:
         """
         Rename a metadata (ie. change its title).
@@ -892,7 +871,7 @@ class Client:
         """
         return self.__call("rename_resource", [resource_id, title])
 
-    def resource(self, resource_id: int) -> Union[Dict, None]:
+    def resource(self, resource_id: int) -> Optional[Dict]:
         """
         Get a resource given its id.
 
@@ -913,7 +892,13 @@ class Client:
         """
         return self.__call("resource", [resource_id])
 
-    def resources(self, collection_id: int, include_metas: bool = True) -> List[Dict]:
+    def resources(
+        self,
+        collection_id: int,
+        include_metas: bool = False,
+        limit_from: int = 0,
+        limit_to: int = 2000,
+    ) -> List[Dict]:
         """
         Get all resources from a collection.
 
@@ -940,7 +925,22 @@ class Client:
         ]
         ```
         """
-        return self.__call("resources", [collection_id, include_metas])
+        return self.__call(
+            "resources", [collection_id, include_metas, limit_from, limit_to]
+        )
+
+    def set_representative_resource(
+        self, collection_id: int, resource_id: int = None
+    ) -> bool:
+        """
+        Choose a Resource that is the best representation of a collection.
+        Typical use case: set a miniature for a collection.
+
+        The Resource does not have to be contained in the collection.
+
+        Resource id may be set set to None/Null.
+        """
+        return self.__call("set_representative_resource", [collection_id, resource_id])
 
     def set_tag(self, uid: str, label: str = None, ark: str = None) -> dict:
         """
